==> jc-1.4.0.tar.gz: soot/DoubleType.h <==
// public class soot.DoubleType

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class f1367e60bd9c6d0a soot_DoubleType
// @dep_class d6846479002a370b soot_PrimType
// @dep_class f801e5c664424a1 soot_Type

// header file dependencies
// @dep_header soot_PrimType

#include "soot/PrimType.h"

#ifndef _JC_soot_DoubleType_H_
#define _JC_soot_DoubleType_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;
struct _jc_java_lang_String$object;
struct _jc_soot_DoubleType$object;
struct _jc_soot_Singletons__24Global$object;
struct _jc_soot_util_Switch$object;

// Typedefs
typedef struct _jc_soot_DoubleType$sub_refs	_jc_soot_DoubleType$sub_refs;
typedef struct _jc_soot_DoubleType$sub_nonrefs	_jc_soot_DoubleType$sub_nonrefs;
typedef struct _jc_soot_DoubleType$refs	_jc_soot_DoubleType$refs;
typedef struct _jc_soot_DoubleType$nonrefs	_jc_soot_DoubleType$nonrefs;
typedef struct _jc_soot_DoubleType$object	_jc_soot_DoubleType$object;

typedef const struct _jc_soot_DoubleType$vmethods	_jc_soot_DoubleType$vmethods;
typedef const struct _jc_soot_DoubleType$vtable	_jc_soot_DoubleType$vtable;
typedef const struct _jc_soot_DoubleType$vtype	_jc_soot_DoubleType$vtype;

// Constructors
extern void _jc_soot_DoubleType$method$_init$bbe94f634b20986f(_jc_env *, struct _jc_soot_DoubleType$object *, struct _jc_soot_Singletons__24Global$object *);

// Virtual methods
extern void _jc_soot_DoubleType$method$apply$cd67f53165014a6d(_jc_env *, struct _jc_soot_DoubleType$object *, struct _jc_object *);
extern jboolean _jc_soot_DoubleType$method$equals$8a15e0625571c581(_jc_env *, struct _jc_soot_DoubleType$object *, struct _jc_java_lang_Object$object *);
extern jint _jc_soot_DoubleType$method$hashCode$53152098849316df(_jc_env *, struct _jc_soot_DoubleType$object *);
extern struct _jc_java_lang_String$object *_jc_soot_DoubleType$method$toString$7ea43b33b80a3070(_jc_env *, struct _jc_soot_DoubleType$object *);

// Virtual method descriptors
extern _jc_method _jc_soot_DoubleType$method_info$apply$cd67f53165014a6d;
extern _jc_method _jc_soot_DoubleType$method_info$equals$8a15e0625571c581;
extern _jc_method _jc_soot_DoubleType$method_info$hashCode$53152098849316df;
extern _jc_method _jc_soot_DoubleType$method_info$toString$7ea43b33b80a3070;

// Static methods
extern struct _jc_soot_DoubleType$object *_jc_soot_DoubleType$method$v$20e2e867e25acc65(_jc_env *);

// Virtual methods structure
struct _jc_soot_DoubleType$vmethods {
	void	(*apply$cd67f53165014a6d)(_jc_env *, struct _jc_soot_DoubleType$object *, struct _jc_object *);
	jboolean	(*equals$8a15e0625571c581)(_jc_env *, struct _jc_soot_DoubleType$object *, struct _jc_java_lang_Object$object *);
	jint	(*hashCode$53152098849316df)(_jc_env *, struct _jc_soot_DoubleType$object *);
	struct _jc_java_lang_String$object	*(*toString$7ea43b33b80a3070)(_jc_env *, struct _jc_soot_DoubleType$object *);
};

// Vtable
struct _jc_soot_DoubleType$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_Type$vmethods	soot_Type;
	_jc_soot_PrimType$vmethods	soot_PrimType;
	_jc_soot_DoubleType$vmethods	soot_DoubleType;
};

// Vtype
struct _jc_soot_DoubleType$vtype {
	_jc_type			type;
	_jc_soot_DoubleType$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_DoubleType$sub_refs {
};

// Reference instance fields (object)
struct _jc_soot_DoubleType$refs {
    _jc_soot_DoubleType$sub_refs	soot_DoubleType;
    _jc_soot_PrimType$sub_refs	soot_PrimType;
    _jc_soot_Type$sub_refs	soot_Type;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_DoubleType$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_soot_DoubleType$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_Type$sub_nonrefs	soot_Type;
    _jc_soot_PrimType$sub_nonrefs	soot_PrimType;
    _jc_soot_DoubleType$sub_nonrefs	soot_DoubleType;
};

// Object instance structure
struct _jc_soot_DoubleType$object {
	_jc_soot_DoubleType$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_DoubleType$vtype	*vtype;
	_jc_soot_DoubleType$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_DoubleType$vtype _jc_soot_DoubleType$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_DoubleType, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_DoubleType$class_object;

#endif	/* _JC_soot_DoubleType_H_ */

==> jc-1.4.6.tar.gz: soot/DoubleType.h <==
// public class soot.DoubleType

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class f1367e60bd9c6d0a soot_DoubleType
// @dep_class d6846479002a370b soot_PrimType
// @dep_class f801e5c664424a1 soot_Type

// header file dependencies
// @dep_header soot_PrimType

#include "soot/PrimType.h"

#ifndef _JC_soot_DoubleType_H_
#define _JC_soot_DoubleType_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;
struct _jc_java_lang_String$object;
struct _jc_soot_DoubleType$object;
struct _jc_soot_Singletons__24Global$object;
struct _jc_soot_util_Switch$object;

// Typedefs
typedef struct _jc_soot_DoubleType$sub_refs	_jc_soot_DoubleType$sub_refs;
typedef struct _jc_soot_DoubleType$sub_nonrefs	_jc_soot_DoubleType$sub_nonrefs;
typedef struct _jc_soot_DoubleType$refs	_jc_soot_DoubleType$refs;
typedef struct _jc_soot_DoubleType$nonrefs	_jc_soot_DoubleType$nonrefs;
typedef struct _jc_soot_DoubleType$object	_jc_soot_DoubleType$object;

typedef const struct _jc_soot_DoubleType$vmethods	_jc_soot_DoubleType$vmethods;
typedef const struct _jc_soot_DoubleType$vtable	_jc_soot_DoubleType$vtable;
typedef const struct _jc_soot_DoubleType$vtype	_jc_soot_DoubleType$vtype;

// Constructors
extern void _jc_soot_DoubleType$method$_init$bbe94f634b20986f(_jc_env *, struct _jc_soot_DoubleType$object *, struct _jc_soot_Singletons__24Global$object *) _JC_JCNI_ATTR;

// Virtual methods
extern void _jc_soot_DoubleType$method$apply$cd67f53165014a6d(_jc_env *, struct _jc_soot_DoubleType$object *, struct _jc_object *) _JC_JCNI_ATTR;
extern jboolean _jc_soot_DoubleType$method$equals$8a15e0625571c581(_jc_env *, struct _jc_soot_DoubleType$object *, struct _jc_java_lang_Object$object *) _JC_JCNI_ATTR;
extern jint _jc_soot_DoubleType$method$hashCode$53152098849316df(_jc_env *, struct _jc_soot_DoubleType$object *) _JC_JCNI_ATTR;
extern struct _jc_java_lang_String$object *_jc_soot_DoubleType$method$toString$7ea43b33b80a3070(_jc_env *, struct _jc_soot_DoubleType$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_soot_DoubleType$method_info$apply$cd67f53165014a6d;
extern _jc_method _jc_soot_DoubleType$method_info$equals$8a15e0625571c581;
extern _jc_method _jc_soot_DoubleType$method_info$hashCode$53152098849316df;
extern _jc_method _jc_soot_DoubleType$method_info$toString$7ea43b33b80a3070;

// Static methods
extern struct _jc_soot_DoubleType$object *_jc_soot_DoubleType$method$v$20e2e867e25acc65(_jc_env *) _JC_JCNI_ATTR;

// Virtual methods structure
struct _jc_soot_DoubleType$vmethods {
	void	(*apply$cd67f53165014a6d)(_jc_env *, struct _jc_soot_DoubleType$object *, struct _jc_object *) _JC_JCNI_ATTR;
	jboolean	(*equals$8a15e0625571c581)(_jc_env *, struct _jc_soot_DoubleType$object *, struct _jc_java_lang_Object$object *) _JC_JCNI_ATTR;
	jint	(*hashCode$53152098849316df)(_jc_env *, struct _jc_soot_DoubleType$object *) _JC_JCNI_ATTR;
	struct _jc_java_lang_String$object	*(*toString$7ea43b33b80a3070)(_jc_env *, struct _jc_soot_DoubleType$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_soot_DoubleType$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_Type$vmethods	soot_Type;
	_jc_soot_PrimType$vmethods	soot_PrimType;
	_jc_soot_DoubleType$vmethods	soot_DoubleType;
};

// Vtype
struct _jc_soot_DoubleType$vtype {
	_jc_type			type;
	_jc_soot_DoubleType$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_DoubleType$sub_refs {
};

// Reference instance fields (object)
struct _jc_soot_DoubleType$refs {
    _jc_soot_DoubleType$sub_refs	soot_DoubleType;
    _jc_soot_PrimType$sub_refs	soot_PrimType;
    _jc_soot_Type$sub_refs	soot_Type;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_DoubleType$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_soot_DoubleType$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_Type$sub_nonrefs	soot_Type;
    _jc_soot_PrimType$sub_nonrefs	soot_PrimType;
    _jc_soot_DoubleType$sub_nonrefs	soot_DoubleType;
};

// Object instance structure
struct _jc_soot_DoubleType$object {
	_jc_soot_DoubleType$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_DoubleType$vtype	*vtype;
	_jc_soot_DoubleType$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_DoubleType$vtype _jc_soot_DoubleType$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_DoubleType, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_DoubleType$class_object;

#endif	/* _JC_soot_DoubleType_H_ */
